/*
  My m25p40 Library
  version 0.1
  2021, electromicro.ru
  License: GNU GPL 2.1
*/

#ifndef MY25P40_H
#define MY25P40_H

#include <Arduino.h>
#include "SPIFlash/SPIFlash.h"

#define FLASH_SECTOR_SIZE 65536

union uib_t {byte b[2]; int i;};
union ulb_t {byte b[4]; unsigned long ul;};
union  lb_t {byte b[4]; long lg;};
union flb_t {byte b[4]; float fl;};

extern uib_t uib;
extern ulb_t ulb;
extern  lb_t  lb;
extern flb_t flb;

class my25p40 : public SPIFlash {
  private:

  public:
    explicit my25p40(uint8_t slaveSelectPin, uint16_t jedecID=0) : SPIFlash(slaveSelectPin, jedecID=0) { };
    
    void checkBusy();
    
    void initInfo();
    void readInfo(uint32_t adr, String s);
    void writeInfo(uint32_t adr, String s);
    
    void erase();
    void erase64K(byte sec);
    
    void writeWord(uint32_t adr, word w);
    word readWord(uint32_t adr);
    
    void writeULong(uint32_t adr, unsigned long ul);
    unsigned long readULong(uint32_t adr);
    
    void writeInt(uint32_t adr, int i);
    int readInt(uint32_t adr);
    
    void writeLong(uint32_t adr, long lg);
    long readLong(uint32_t adr);
    
    void writeFloat(uint32_t adr, float fl);
    float readFloat(uint32_t adr);
    
    void writeChars(uint32_t adr, char chs[], byte len);
    void readChars(uint32_t adr, char *buf, byte len);
    
    void writeString(uint32_t adr, String s);
    String readString(uint32_t adr, byte len);
};

#endif // #ifndef MY25P40_H
